import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface WorkflowConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account id of the workflow.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#account_id Workflow#account_id}
    */
    readonly accountId?: number;
    /**
    * Indicates whether the destinations are enabled.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#destinations_enabled Workflow#destinations_enabled}
    */
    readonly destinationsEnabled?: boolean | cdktf.IResolvable;
    /**
    * Indicates whether the enrichments are enabled.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#enrichments_enabled Workflow#enrichments_enabled}
    */
    readonly enrichmentsEnabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#id Workflow#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The type of the muting rule handling. One of: (NOTIFY_ALL_ISSUES, DONT_NOTIFY_FULLY_MUTED_ISSUES, DONT_NOTIFY_FULLY_OR_PARTIALLY_MUTED_ISSUES).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#muting_rules_handling Workflow#muting_rules_handling}
    */
    readonly mutingRulesHandling: string;
    /**
    * (Required) The name of the workflow.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#name Workflow#name}
    */
    readonly name: string;
    /**
    * Indicates whether the workflow is enabled.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#workflow_enabled Workflow#workflow_enabled}
    */
    readonly workflowEnabled?: boolean | cdktf.IResolvable;
    /**
    * destination_configuration block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#destination_configuration Workflow#destination_configuration}
    */
    readonly destinationConfiguration: WorkflowDestinationConfiguration[] | cdktf.IResolvable;
    /**
    * enrichments block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#enrichments Workflow#enrichments}
    */
    readonly enrichments?: WorkflowEnrichments;
    /**
    * issues_filter block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#issues_filter Workflow#issues_filter}
    */
    readonly issuesFilter: WorkflowIssuesFilter;
}
export interface WorkflowDestinationConfiguration {
    /**
    * (Required) Destination's channel id.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#channel_id Workflow#channel_id}
    */
    readonly channelId: string;
}
export declare function workflowDestinationConfigurationToTerraform(struct?: WorkflowDestinationConfiguration | cdktf.IResolvable): any;
export declare class WorkflowDestinationConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkflowDestinationConfiguration | cdktf.IResolvable | undefined;
    set internalValue(value: WorkflowDestinationConfiguration | cdktf.IResolvable | undefined);
    private _channelId?;
    get channelId(): string;
    set channelId(value: string);
    get channelIdInput(): string | undefined;
    get name(): string;
    get type(): string;
}
export declare class WorkflowDestinationConfigurationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkflowDestinationConfiguration[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkflowDestinationConfigurationOutputReference;
}
export interface WorkflowEnrichmentsNrqlConfigurations {
    /**
    * enrichment's NRQL query
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#query Workflow#query}
    */
    readonly query: string;
}
export declare function workflowEnrichmentsNrqlConfigurationsToTerraform(struct?: WorkflowEnrichmentsNrqlConfigurations | cdktf.IResolvable): any;
export declare class WorkflowEnrichmentsNrqlConfigurationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkflowEnrichmentsNrqlConfigurations | cdktf.IResolvable | undefined;
    set internalValue(value: WorkflowEnrichmentsNrqlConfigurations | cdktf.IResolvable | undefined);
    private _query?;
    get query(): string;
    set query(value: string);
    get queryInput(): string | undefined;
}
export declare class WorkflowEnrichmentsNrqlConfigurationsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkflowEnrichmentsNrqlConfigurations[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkflowEnrichmentsNrqlConfigurationsOutputReference;
}
export interface WorkflowEnrichmentsNrql {
    /**
    * (Required) Enrichment's name.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#name Workflow#name}
    */
    readonly name: string;
    /**
    * configurations block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#configurations Workflow#configurations}
    */
    readonly configurations: WorkflowEnrichmentsNrqlConfigurations[] | cdktf.IResolvable;
}
export declare function workflowEnrichmentsNrqlToTerraform(struct?: WorkflowEnrichmentsNrql | cdktf.IResolvable): any;
export declare class WorkflowEnrichmentsNrqlOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkflowEnrichmentsNrql | cdktf.IResolvable | undefined;
    set internalValue(value: WorkflowEnrichmentsNrql | cdktf.IResolvable | undefined);
    get accountId(): number;
    get enrichmentId(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get type(): string;
    private _configurations;
    get configurations(): WorkflowEnrichmentsNrqlConfigurationsList;
    putConfigurations(value: WorkflowEnrichmentsNrqlConfigurations[] | cdktf.IResolvable): void;
    get configurationsInput(): cdktf.IResolvable | WorkflowEnrichmentsNrqlConfigurations[] | undefined;
}
export declare class WorkflowEnrichmentsNrqlList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkflowEnrichmentsNrql[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkflowEnrichmentsNrqlOutputReference;
}
export interface WorkflowEnrichments {
    /**
    * nrql block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#nrql Workflow#nrql}
    */
    readonly nrql: WorkflowEnrichmentsNrql[] | cdktf.IResolvable;
}
export declare function workflowEnrichmentsToTerraform(struct?: WorkflowEnrichmentsOutputReference | WorkflowEnrichments): any;
export declare class WorkflowEnrichmentsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WorkflowEnrichments | undefined;
    set internalValue(value: WorkflowEnrichments | undefined);
    private _nrql;
    get nrql(): WorkflowEnrichmentsNrqlList;
    putNrql(value: WorkflowEnrichmentsNrql[] | cdktf.IResolvable): void;
    get nrqlInput(): cdktf.IResolvable | WorkflowEnrichmentsNrql[] | undefined;
}
export interface WorkflowIssuesFilterPredicates {
    /**
    * (Required) predicate's attribute.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#attribute Workflow#attribute}
    */
    readonly attribute: string;
    /**
    * The type of the operator. One of: (CONTAINS, DOES_NOT_CONTAIN, DOES_NOT_EQUAL, DOES_NOT_EXACTLY_MATCH, ENDS_WITH, EQUAL, EXACTLY_MATCHES, GREATER_OR_EQUAL, GREATER_THAN, IS, IS_NOT, LESS_OR_EQUAL, LESS_THAN, STARTS_WITH).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#operator Workflow#operator}
    */
    readonly operator: string;
    /**
    * List of predicate values.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#values Workflow#values}
    */
    readonly values: string[];
}
export declare function workflowIssuesFilterPredicatesToTerraform(struct?: WorkflowIssuesFilterPredicates | cdktf.IResolvable): any;
export declare class WorkflowIssuesFilterPredicatesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkflowIssuesFilterPredicates | cdktf.IResolvable | undefined;
    set internalValue(value: WorkflowIssuesFilterPredicates | cdktf.IResolvable | undefined);
    private _attribute?;
    get attribute(): string;
    set attribute(value: string);
    get attributeInput(): string | undefined;
    private _operator?;
    get operator(): string;
    set operator(value: string);
    get operatorInput(): string | undefined;
    private _values?;
    get values(): string[];
    set values(value: string[]);
    get valuesInput(): string[] | undefined;
}
export declare class WorkflowIssuesFilterPredicatesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkflowIssuesFilterPredicates[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkflowIssuesFilterPredicatesOutputReference;
}
export interface WorkflowIssuesFilter {
    /**
    * (Required) Filter's name.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#name Workflow#name}
    */
    readonly name: string;
    /**
    * (Required) The type of the filter. One of: (FILTER, VIEW).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#type Workflow#type}
    */
    readonly type: string;
    /**
    * predicates block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/workflow#predicates Workflow#predicates}
    */
    readonly predicates?: WorkflowIssuesFilterPredicates[] | cdktf.IResolvable;
}
export declare function workflowIssuesFilterToTerraform(struct?: WorkflowIssuesFilterOutputReference | WorkflowIssuesFilter): any;
export declare class WorkflowIssuesFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WorkflowIssuesFilter | undefined;
    set internalValue(value: WorkflowIssuesFilter | undefined);
    get filterId(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _predicates;
    get predicates(): WorkflowIssuesFilterPredicatesList;
    putPredicates(value: WorkflowIssuesFilterPredicates[] | cdktf.IResolvable): void;
    resetPredicates(): void;
    get predicatesInput(): cdktf.IResolvable | WorkflowIssuesFilterPredicates[] | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/workflow newrelic_workflow}
*/
export declare class Workflow extends cdktf.TerraformResource {
    static readonly tfResourceType = "newrelic_workflow";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/workflow newrelic_workflow} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options WorkflowConfig
    */
    constructor(scope: Construct, id: string, config: WorkflowConfig);
    private _accountId?;
    get accountId(): number;
    set accountId(value: number);
    resetAccountId(): void;
    get accountIdInput(): number | undefined;
    private _destinationsEnabled?;
    get destinationsEnabled(): boolean | cdktf.IResolvable;
    set destinationsEnabled(value: boolean | cdktf.IResolvable);
    resetDestinationsEnabled(): void;
    get destinationsEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _enrichmentsEnabled?;
    get enrichmentsEnabled(): boolean | cdktf.IResolvable;
    set enrichmentsEnabled(value: boolean | cdktf.IResolvable);
    resetEnrichmentsEnabled(): void;
    get enrichmentsEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get lastRun(): string;
    private _mutingRulesHandling?;
    get mutingRulesHandling(): string;
    set mutingRulesHandling(value: string);
    get mutingRulesHandlingInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _workflowEnabled?;
    get workflowEnabled(): boolean | cdktf.IResolvable;
    set workflowEnabled(value: boolean | cdktf.IResolvable);
    resetWorkflowEnabled(): void;
    get workflowEnabledInput(): boolean | cdktf.IResolvable | undefined;
    get workflowId(): string;
    private _destinationConfiguration;
    get destinationConfiguration(): WorkflowDestinationConfigurationList;
    putDestinationConfiguration(value: WorkflowDestinationConfiguration[] | cdktf.IResolvable): void;
    get destinationConfigurationInput(): cdktf.IResolvable | WorkflowDestinationConfiguration[] | undefined;
    private _enrichments;
    get enrichments(): WorkflowEnrichmentsOutputReference;
    putEnrichments(value: WorkflowEnrichments): void;
    resetEnrichments(): void;
    get enrichmentsInput(): WorkflowEnrichments | undefined;
    private _issuesFilter;
    get issuesFilter(): WorkflowIssuesFilterOutputReference;
    putIssuesFilter(value: WorkflowIssuesFilter): void;
    get issuesFilterInput(): WorkflowIssuesFilter | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
